# VScode, PyCharm, Spyder, JupyterLab integration

<!-- #region -->
You can launch jupyterlab or VSCode from the anaconda navigator

Make sure you launch:

- JupyterLab: recommended for new users and for learning
- VSCode: for more advanced users.


using the anaconda navigator so that your path is setup correctly.

![navigator](https://i.imgur.com/e1fSszF.png)
<!-- #endregion -->

## JupyterLab

The gdsfactory installer installs Jupyterlab

You can launch JupyterLab from the anaconda navigator.

Jupyter Notebooks are a great way to go through tutorials like this one.

![jupyterlab](https://i.imgur.com/WX0XEGg.png)


## VScode

VSCode is a free open source popular editor that you can [install](https://code.visualstudio.com/)

gdsfactory has a VScode extension that you can install from the marketplace.

The extension provides you with useful code snippets

![extension](https://i.imgur.com/89OPCQ1.png)

Make sure you choose the correct gdsfactory path.

![vscode](https://i.imgur.com/g7IL3D3.png)


## PyCharm

PyCharm is also a popular python IDE that you can [install](https://www.jetbrains.com/pycharm/)

![pycharm](https://i.imgur.com/bK11wZW.png)


## Spyder

Spyder is the most similar IDE to Matlab.

You can install spyder from the anaconda prompt using `conda install spyder -y`

![spyder ipython](https://i.imgur.com/FotCgPh.png)
